==> openshift-model-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/ClusterRoleScopeRestrictionFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ClusterRoleScopeRestrictionFluent<A extends ClusterRoleScopeRestrictionFluent<A>> extends Fluent<A> {


    public Boolean isAllowEscalation();
    public A withAllowEscalation(Boolean allowEscalation);
    public Boolean hasAllowEscalation();
    public A withNewAllowEscalation(String arg1);
    public A withNewAllowEscalation(boolean arg1);
    public A addToNamespaces(int index,String item);
    public A setToNamespaces(int index,String item);
    public A addToNamespaces(String... items);
    public A addAllToNamespaces(Collection<String> items);
    public A removeFromNamespaces(String... items);
    public A removeAllFromNamespaces(Collection<String> items);
    public List<String> getNamespaces();
    public String getNamespace(int index);
    public String getFirstNamespace();
    public String getLastNamespace();
    public String getMatchingNamespace(Predicate<String> predicate);
    public Boolean hasMatchingNamespace(Predicate<String> predicate);
    public A withNamespaces(List<String> namespaces);
    public A withNamespaces(String... namespaces);
    public Boolean hasNamespaces();
    public A addNewNamespace(String arg1);
    public A addNewNamespace(StringBuilder arg1);
    public A addNewNamespace(StringBuffer arg1);
    public A addToRoleNames(int index,String item);
    public A setToRoleNames(int index,String item);
    public A addToRoleNames(String... items);
    public A addAllToRoleNames(Collection<String> items);
    public A removeFromRoleNames(String... items);
    public A removeAllFromRoleNames(Collection<String> items);
    public List<String> getRoleNames();
    public String getRoleName(int index);
    public String getFirstRoleName();
    public String getLastRoleName();
    public String getMatchingRoleName(Predicate<String> predicate);
    public Boolean hasMatchingRoleName(Predicate<String> predicate);
    public A withRoleNames(List<String> roleNames);
    public A withRoleNames(String... roleNames);
    public Boolean hasRoleNames();
    public A addNewRoleName(String arg1);
    public A addNewRoleName(StringBuilder arg1);
    public A addNewRoleName(StringBuffer arg1);
}

==> openshift-model-5.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/ClusterRoleScopeRestrictionFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ClusterRoleScopeRestrictionFluent<A extends ClusterRoleScopeRestrictionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public Boolean getAllowEscalation();
    public A withAllowEscalation(Boolean allowEscalation);
    public Boolean hasAllowEscalation();
    public A withNewAllowEscalation(String arg1);
    public A withNewAllowEscalation(boolean arg1);
    public A addToNamespaces(int index,String item);
    public A setToNamespaces(int index,String item);
    public A addToNamespaces(String... items);
    public A addAllToNamespaces(Collection<String> items);
    public A removeFromNamespaces(String... items);
    public A removeAllFromNamespaces(Collection<String> items);
    public List<String> getNamespaces();
    public String getNamespace(int index);
    public String getFirstNamespace();
    public String getLastNamespace();
    public String getMatchingNamespace(Predicate<String> predicate);
    public Boolean hasMatchingNamespace(Predicate<String> predicate);
    public A withNamespaces(List<String> namespaces);
    public A withNamespaces(String... namespaces);
    public Boolean hasNamespaces();
    public A addNewNamespace(StringBuilder arg1);
    public A addNewNamespace(int[] arg1,int arg2,int arg3);
    public A addNewNamespace(char[] arg1);
    public A addNewNamespace(StringBuffer arg1);
    public A addNewNamespace(byte[] arg1,int arg2);
    public A addNewNamespace(byte[] arg1);
    public A addNewNamespace(char[] arg1,int arg2,int arg3);
    public A addNewNamespace(byte[] arg1,int arg2,int arg3);
    public A addNewNamespace(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewNamespace(String arg1);
    public A addToRoleNames(int index,String item);
    public A setToRoleNames(int index,String item);
    public A addToRoleNames(String... items);
    public A addAllToRoleNames(Collection<String> items);
    public A removeFromRoleNames(String... items);
    public A removeAllFromRoleNames(Collection<String> items);
    public List<String> getRoleNames();
    public String getRoleName(int index);
    public String getFirstRoleName();
    public String getLastRoleName();
    public String getMatchingRoleName(Predicate<String> predicate);
    public Boolean hasMatchingRoleName(Predicate<String> predicate);
    public A withRoleNames(List<String> roleNames);
    public A withRoleNames(String... roleNames);
    public Boolean hasRoleNames();
    public A addNewRoleName(StringBuilder arg1);
    public A addNewRoleName(int[] arg1,int arg2,int arg3);
    public A addNewRoleName(char[] arg1);
    public A addNewRoleName(StringBuffer arg1);
    public A addNewRoleName(byte[] arg1,int arg2);
    public A addNewRoleName(byte[] arg1);
    public A addNewRoleName(char[] arg1,int arg2,int arg3);
    public A addNewRoleName(byte[] arg1,int arg2,int arg3);
    public A addNewRoleName(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewRoleName(String arg1);
}
